pub struct OffsetAccess {
pub access: Access<'static>,
pub offset: Option<usize>,
}Expand description
An Access combined with an offset for more helpful error reporting.
Fields
access: Access<'static>The Access itself.
offset: Option<usize>A character offset in the string the path was parsed from.