ReflectPath

Trait ReflectPath 

pub trait ReflectPath<'a>: Sized {
    // Required methods
    fn reflect_element(
        self,
        root: &dyn PartialReflect,
    ) -> Result<&dyn PartialReflect, ReflectPathError<'a>>;
    fn reflect_element_mut(
        self,
        root: &mut dyn PartialReflect,
    ) -> Result<&mut dyn PartialReflect, ReflectPathError<'a>>;

    // Provided methods
    fn element<T: Reflect>(
        self,
        root: &dyn PartialReflect,
    ) -> Result<&T, ReflectPathError<'a>> { ... }
    fn element_mut<T: Reflect>(
        self,
        root: &mut dyn PartialReflect,
    ) -> Result<&mut T, ReflectPathError<'a>> { ... }
}
Something that can be interpreted as a reflection path in GetPath.

Required Methods

fn reflect_element( self, root: &dyn PartialReflect, ) -> Result<&dyn PartialReflect, ReflectPathError<'a>>

Gets a reference to the specified element on the given Reflect object.

See GetPath::reflect_path for more details, see element if you want a typed return value.

fn reflect_element_mut( self, root: &mut dyn PartialReflect, ) -> Result<&mut dyn PartialReflect, ReflectPathError<'a>>

Gets a mutable reference to the specified element on the given Reflect object.

See GetPath::reflect_path_mut for more details.

Provided Methods

fn element<T: Reflect>( self, root: &dyn PartialReflect, ) -> Result<&T, ReflectPathError<'a>>

Gets a &T to the specified element on the given Reflect object.

See GetPath::path for more details.

fn element_mut<T: Reflect>( self, root: &mut dyn PartialReflect, ) -> Result<&mut T, ReflectPathError<'a>>

Gets a &mut T to the specified element on the given Reflect object.

See GetPath::path_mut for more details.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a> ReflectPath<'a> for &'a str

Implementors

Source

impl<'a> ReflectPath<'a> for &'a ParsedPath